<?php

/**
 * @file
 * Contains \Drupal\video_embed_wistia\Plugin\video_embed_field\Provider\Wistia.
 */

namespace Drupal\video_embed_wistia\Plugin\video_embed_field\Provider;

use Drupal\Core\Url;
use Drupal\video_embed_field\ProviderPluginBase;

/**
 * @VideoEmbedProvider(
 *   id = "wistia",
 *   title = @Translation("Wistia")
 * )
 */
class Wistia extends ProviderPluginBase {

  /**
   * {@inheritdoc}
   */
  public function renderEmbedCode($width, $height, $autoplay, $title_format = NULL, $use_title_fallback = TRUE) {
    $embed_code = [
      '#type' => 'video_embed_iframe',
      '#provider' => 'wistia',
      '#url' => sprintf('https://fast.wistia.com/embed/iframe/%s', $this->getVideoId()),
      '#query' => [
        'autoPlay' => $autoplay,
        'muted' => $autoplay,
      ],
      '#attributes' => [
        'width' => $width,
        'height' => $height,
        'frameborder' => '0',
        'allowfullscreen' => 'allowfullscreen',
        'class' => 'wistia_embed'
      ],
    ];
    $title = $this->getName($title_format, $use_title_fallback);
    if (isset($title)) {
      $embed_code['#attributes']['title'] = $title;
    }
    return $embed_code;
  }

  /**
   * {@inheritdoc}
   */
  public function getRemoteThumbnailUrl() {
    return $this->oEmbedData()['thumbnail_url'] ?? NULL;
  }

  /**
   * {@inheritdoc}
   */
  public static function getIdFromInput($input) {
    preg_match('/^https?:\/\/(?:.+)?(?:wistia\.com|wi\.st|wistia\.net)(?:\/(?:medias|embed\/iframe|embed))*\/(?<id>[0-9A-Za-z]+)(?:\.\w*)?$/', $input, $matches);
    return $matches['id'] ?? FALSE;
  }

  /**
   * Get the Wistia oembed data.
   *
   * @return array|null
   *   An array of data from the oembed endpoint or NULL if download failed.
   */
  protected function oEmbedData(): ?array {
    $oembed_url = Url::fromUri('https://fast.wistia.net/oembed', ['query' => ['url' => $this->getInput()]]);
    return $this->downloadJsonData($oembed_url->toString());
  }

  /**
   * {@inheritdoc}
   */
  public function getName($title_format = NULL, $use_title_fallback = TRUE) {
    return $this->formatTitle(
      $this->oEmbedData()['title'] ?? NULL,
      $title_format,
      $use_title_fallback
    );
  }
}
